<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 09/14/2008 *
 * ===================                          Last change: 09/14/2008 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : purge-inactive.php                               *
 * -------------------------------------------------------------------- *
 * Short description : Purge of inactive users                          *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auto-Loeschung von inaktiven Mitgliedern         *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * Needs to be in all Files and every File needs "svn propset           *
 * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Abort if autopurge is not active or disabled by admin
if ((!isExtensionActive('autopurge')) || (getConfig('auto_purge_active') != 'Y')) {
	// Abort here
	return false;
} // END - if

// Shall I look for inactive accounts and autopurge inactive accounts?
if (getConfig('autopurge_inactive') == 'Y') {
	// Init SQLs
	initSqls();

	// Init exclusion list
	$EXCLUDE_LIST = '';
	if (getConfig('def_refid') > 0) {
		$EXCLUDE_LIST = " AND d.userid != ".getConfig('def_refid');
	} // END - if

	// Check for more extensions
	if (isExtensionActive('beg'))     $EXCLUDE_LIST .= " AND d.userid != ".getConfig('beg_userid')."";
	if (isExtensionActive('bonus'))   $EXCLUDE_LIST .= " AND d.userid != ".getConfig('bonus_userid')."";
	if (isExtensionActive('doubler')) $EXCLUDE_LIST .= " AND d.userid != ".getConfig('doubler_userid')."";

	// Check for new holiday extension
	if (getExtensionVersion('holiday') >= '0.1.3') {
		// Include only users with no active holiday
		$EXCLUDE_LIST .= " AND d.`holiday_active`='N'";
	} // END - if

	// Check for all accounts
	$result_inactive = SQL_QUERY_ESC("SELECT d.userid, d.email, d.last_online
FROM
	`{?_MYSQL_PREFIX?}_user_data` AS d
WHERE
	d.status='CONFIRMED' AND
	d.joined < (UNIX_TIMESTAMP() - %s) AND
	d.last_online < (UNIX_TIMESTAMP() - %s) AND
	d.ap_notified < (UNIX_TIMESTAMP() - %s)
	".$EXCLUDE_LIST."
ORDER BY
	d.userid ASC",
		array(
			getConfig('ap_inactive_since'),
			getConfig('ap_inactive_since'),
			getConfig('ap_inactive_since')
		), __FILE__, __LINE__);

	if (SQL_NUMROWS($result_inactive) > 0) {
		// Prepare variables and constants...
		$useridsContent = '';
		$content['since'] = (getConfig('ap_inactive_since') / 60 / 60);
		$content['time']  = (getConfig('ap_inactive_time')  / 60 / 60);

		// Mark found accounts as inactive and send an email
		while ($content = SQL_FETCHARRAY($result_inactive)) {
			// Remember userids for the admin
			$useridsContent .= $content['userid'].", ";

			// Get date/time from timestamp
			$content['last_online'] = generateDateTime($content['last_online'], 0);

			// Load mail template
			$message = loadEmailTemplate('member_autopurge_inactive', $content, bigintval($content['userid']));
			sendEmail($content['email'], getMessage('AUTOPURGE_MEMBER_INACTIVE_SUBJECT'), $message);

			// Update this account
			addSql(SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ap_notified`=UNIX_TIMESTAMP() WHERE `userid`=%s LIMIT 1",
				array(bigintval($content['userid'])), __FILE__, __LINE__, false));
		} // END - while

		// Remove last comma
		$useridsContent = str_replace(', ', "\n", substr($useridsContent, 0, -2));

		// Send mail notification to admin
		sendAdminNotification(getMessage('AUTOPURGE_ADMIN_INACTIVE_SUBJECT'), 'admin_autopurge_inactive', $useridsContent, '');
	} // END - if

	// Free memory
	SQL_FREERESULT($result_inactive);

	// Now let's have a look for inactive accounts we want to delete we newly use the same exclude list
	// here for e.g. excluding holiday users
	$result_inactive = SQL_QUERY_ESC("SELECT d.userid, d.email, d.last_online
FROM `{?_MYSQL_PREFIX?}_user_data` AS d
WHERE `status`='CONFIRMED' AND `joined` < (UNIX_TIMESTAMP() - %s) AND `last_online` < (UNIX_TIMESTAMP() - %s) AND `ap_notified` < (UNIX_TIMESTAMP() - %s)
".$EXCLUDE_LIST."
ORDER BY `userid` ASC",
		array(
			getConfig('ap_inactive_since'),
			getConfig('ap_inactive_since'),
			getConfig('ap_inactive_time')
		), __FILE__, __LINE__);

	if (SQL_NUMROWS($result_inactive) > 0) {
		// Prepare variable...
		$useridsContent = '';

		// Delete inactive accounts
		while ($content = SQL_FETCHARRAY($result_inactive)) {
			// Remember userids for the admin
			$useridsContent .= $content['userid'] . ', ';

			// Get date/time from timestamp
			$content['last_online'] = generateDateTime($content['last_online'], 0);

			// Finnaly delete this inactive account
			deleteUserAccount($content['userid'], loadEmailTemplate('member_autopurge_delete', $content['last_online'], ''));
		} // END - while

		// Remove last comma
		$useridsContent = str_replace(', ', "\n", substr($useridsContent, 0, -2));

		// Send mail notification to admin
		if (getConfig('ap_in_notify') == 'Y') {
			sendAdminNotification(getMessage('AUTOPURGE_ADMIN_DELETE_SUBJECT'), 'admin_autopurge_delete', $useridsContent, '');
		} // END - if
	} // END - if

	// Free memory
	SQL_FREERESULT($result_inactive);

	// Run all SQLs
	runFilterChain('run_sqls');
} // END - if

// [EOF]
?>
